# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_codebuild.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_codebuild.proto\x12\x19oak9.tython.aws.codebuild\x1a\x13shared/shared.proto\"\x88\x01\n\x10ProjectVpcConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07subnets\x18\x02 \x03(\t\x12\x0e\n\x06vpc_id\x18\x03 \x01(\t\x12\x1a\n\x12security_group_ids\x18\x04 \x03(\t\"^\n\x11ProjectSourceAuth\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08resource\x18\x02 \x01(\t\"x\n\x18ProjectBuildStatusConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63ontext\x18\x02 \x01(\t\x12\x12\n\ntarget_url\x18\x03 \x01(\t\"o\n\x1aProjectGitSubmodulesConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x66\x65tch_submodules\x18\x02 \x01(\x08\"\xb9\x03\n\rProjectSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13report_build_status\x18\x02 \x01(\x08\x12:\n\x04\x61uth\x18\x03 \x01(\x0b\x32,.oak9.tython.aws.codebuild.ProjectSourceAuth\x12\x19\n\x11source_identifier\x18\x04 \x01(\t\x12\x12\n\nbuild_spec\x18\x05 \x01(\t\x12\x17\n\x0fgit_clone_depth\x18\x06 \x01(\x05\x12P\n\x13\x62uild_status_config\x18\x07 \x01(\x0b\x32\x33.oak9.tython.aws.codebuild.ProjectBuildStatusConfig\x12T\n\x15git_submodules_config\x18\x08 \x01(\x0b\x32\x35.oak9.tython.aws.codebuild.ProjectGitSubmodulesConfig\x12\x14\n\x0cinsecure_ssl\x18\t \x01(\x08\x12\x10\n\x08location\x18\n \x01(\t\"M\n\x12ProjectFilterGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa8\x01\n\x16ProjectProjectTriggers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\rfilter_groups\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.codebuild.ProjectFilterGroup\x12\x0f\n\x07webhook\x18\x03 \x01(\x08\"\xfe\x01\n\x10ProjectArtifacts\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x1b\n\x13\x61rtifact_identifier\x18\x03 \x01(\t\x12\x1e\n\x16override_artifact_name\x18\x04 \x01(\x08\x12\x11\n\tpackaging\x18\x05 \x01(\t\x12\x1b\n\x13\x65ncryption_disabled\x18\x06 \x01(\x08\x12\x10\n\x08location\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x16\n\x0enamespace_type\x18\t \x01(\t\"\x8f\x01\n\x1bProjectCloudWatchLogsConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x12\n\ngroup_name\x18\x03 \x01(\t\x12\x13\n\x0bstream_name\x18\x04 \x01(\t\"\x8d\x01\n\x13ProjectS3LogsConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x1b\n\x13\x65ncryption_disabled\x18\x03 \x01(\x08\x12\x10\n\x08location\x18\x04 \x01(\t\"\xdf\x01\n\x11ProjectLogsConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x10\x63loud_watch_logs\x18\x02 \x01(\x0b\x32\x36.oak9.tython.aws.codebuild.ProjectCloudWatchLogsConfig\x12?\n\x07s3_logs\x18\x03 \x01(\x0b\x32..oak9.tython.aws.codebuild.ProjectS3LogsConfig\"\xad\x01\n ProjectProjectFileSystemLocation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bmount_point\x18\x02 \x01(\t\x12\x12\n\nidentifier\x18\x03 \x01(\t\x12\x15\n\rmount_options\x18\x04 \x01(\t\x12\x10\n\x08location\x18\x05 \x01(\t\"r\n\x1aProjectEnvironmentVariable\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x85\x01\n\x19ProjectRegistryCredential\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ncredential\x18\x02 \x01(\t\x12\x1b\n\x13\x63redential_provider\x18\x03 \x01(\t\"\xee\x02\n\x12ProjectEnvironment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12T\n\x15\x65nvironment_variables\x18\x02 \x03(\x0b\x32\x35.oak9.tython.aws.codebuild.ProjectEnvironmentVariable\x12\x17\n\x0fprivileged_mode\x18\x03 \x01(\x08\x12#\n\x1bimage_pull_credentials_type\x18\x04 \x01(\t\x12\r\n\x05image\x18\x05 \x01(\t\x12Q\n\x13registry_credential\x18\x06 \x01(\x0b\x32\x34.oak9.tython.aws.codebuild.ProjectRegistryCredential\x12\x14\n\x0c\x63ompute_type\x18\x07 \x01(\t\x12\x13\n\x0b\x63\x65rtificate\x18\x08 \x01(\t\"\x89\x01\n\x1bProjectProjectSourceVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11source_identifier\x18\x02 \x01(\t\x12\x16\n\x0esource_version\x18\x03 \x01(\t\"\x92\x01\n\x18ProjectBatchRestrictions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x63ompute_types_allowed\x18\x02 \x03(\t\x12\x1e\n\x16maximum_builds_allowed\x18\x03 \x01(\x05\"\xee\x01\n\x1eProjectProjectBuildBatchConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x63ombine_artifacts\x18\x02 \x01(\x08\x12\x14\n\x0cservice_role\x18\x03 \x01(\t\x12\x17\n\x0ftimeout_in_mins\x18\x04 \x01(\x05\x12I\n\x0crestrictions\x18\x05 \x01(\x0b\x32\x33.oak9.tython.aws.codebuild.ProjectBatchRestrictions\"o\n\x13ProjectProjectCache\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05modes\x18\x02 \x03(\t\x12\x10\n\x08location\x18\x03 \x01(\t\"\xcd\t\n\x07Project\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12?\n\nvpc_config\x18\x03 \x01(\x0b\x32+.oak9.tython.aws.codebuild.ProjectVpcConfig\x12\x43\n\x11secondary_sources\x18\x04 \x03(\x0b\x32(.oak9.tython.aws.codebuild.ProjectSource\x12\x16\n\x0e\x65ncryption_key\x18\x05 \x01(\t\x12\x16\n\x0esource_version\x18\x06 \x01(\t\x12\x43\n\x08triggers\x18\x07 \x01(\x0b\x32\x31.oak9.tython.aws.codebuild.ProjectProjectTriggers\x12H\n\x13secondary_artifacts\x18\x08 \x03(\x0b\x32+.oak9.tython.aws.codebuild.ProjectArtifacts\x12\x38\n\x06source\x18\t \x01(\x0b\x32(.oak9.tython.aws.codebuild.ProjectSource\x12\x0c\n\x04name\x18\n \x01(\t\x12>\n\tartifacts\x18\x0b \x01(\x0b\x32+.oak9.tython.aws.codebuild.ProjectArtifacts\x12\x15\n\rbadge_enabled\x18\x0c \x01(\x08\x12\x41\n\x0blogs_config\x18\r \x01(\x0b\x32,.oak9.tython.aws.codebuild.ProjectLogsConfig\x12\x14\n\x0cservice_role\x18\x0e \x01(\t\x12!\n\x19queued_timeout_in_minutes\x18\x0f \x01(\x05\x12Z\n\x15\x66ile_system_locations\x18\x10 \x03(\x0b\x32;.oak9.tython.aws.codebuild.ProjectProjectFileSystemLocation\x12\x42\n\x0b\x65nvironment\x18\x11 \x01(\x0b\x32-.oak9.tython.aws.codebuild.ProjectEnvironment\x12Y\n\x19secondary_source_versions\x18\x12 \x03(\x0b\x32\x36.oak9.tython.aws.codebuild.ProjectProjectSourceVersion\x12U\n\x12\x62uild_batch_config\x18\x13 \x01(\x0b\x32\x39.oak9.tython.aws.codebuild.ProjectProjectBuildBatchConfig\x12:\n\x04tags\x18\x14 \x03(\x0b\x32,.oak9.tython.aws.codebuild.Project.TagsEntry\x12\x1a\n\x12timeout_in_minutes\x18\x15 \x01(\x05\x12=\n\x05\x63\x61\x63he\x18\x16 \x01(\x0b\x32..oak9.tython.aws.codebuild.ProjectProjectCache\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x02\n\tCodeBuild\x12\x33\n\x07project\x18\x01 \x03(\x0b\x32\".oak9.tython.aws.codebuild.Project\x12<\n\x0creport_group\x18\x02 \x03(\x0b\x32&.oak9.tython.aws.codebuild.ReportGroup\x12\x46\n\x11source_credential\x18\x03 \x03(\x0b\x32+.oak9.tython.aws.codebuild.SourceCredential\x12O\n\x16project_webhook_filter\x18\x04 \x03(\x0b\x32/.oak9.tython.aws.codebuild.ProjectWebhookFilter\"\xc0\x01\n\x1fReportGroupS3ReportExportConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x11\n\tpackaging\x18\x04 \x01(\t\x12\x16\n\x0e\x65ncryption_key\x18\x05 \x01(\t\x12\x1b\n\x13\x65ncryption_disabled\x18\x06 \x01(\x08\"\xc8\x01\n\x1dReportGroupReportExportConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x0es3_destination\x18\x02 \x01(\x0b\x32:.oak9.tython.aws.codebuild.ReportGroupS3ReportExportConfig\x12\x1a\n\x12\x65xport_config_type\x18\x03 \x01(\t\"\xb8\x02\n\x0bReportGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04type\x18\x02 \x01(\t\x12O\n\rexport_config\x18\x03 \x01(\x0b\x32\x38.oak9.tython.aws.codebuild.ReportGroupReportExportConfig\x12\x16\n\x0e\x64\x65lete_reports\x18\x04 \x01(\x08\x12>\n\x04tags\x18\x05 \x03(\x0b\x32\x30.oak9.tython.aws.codebuild.ReportGroup.TagsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x94\x01\n\x10SourceCredential\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bserver_type\x18\x02 \x01(\t\x12\x10\n\x08username\x18\x03 \x01(\t\x12\r\n\x05token\x18\x04 \x01(\t\x12\x11\n\tauth_type\x18\x05 \x01(\t\"\x81\x01\n\x14ProjectWebhookFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07pattern\x18\x02 \x01(\t\x12\x1f\n\x17\x65xclude_matched_pattern\x18\x03 \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_codebuild_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROJECT_TAGSENTRY._options = None
  _PROJECT_TAGSENTRY._serialized_options = b'8\001'
  _REPORTGROUP_TAGSENTRY._options = None
  _REPORTGROUP_TAGSENTRY._serialized_options = b'8\001'
  _PROJECTVPCCONFIG._serialized_start=76
  _PROJECTVPCCONFIG._serialized_end=212
  _PROJECTSOURCEAUTH._serialized_start=214
  _PROJECTSOURCEAUTH._serialized_end=308
  _PROJECTBUILDSTATUSCONFIG._serialized_start=310
  _PROJECTBUILDSTATUSCONFIG._serialized_end=430
  _PROJECTGITSUBMODULESCONFIG._serialized_start=432
  _PROJECTGITSUBMODULESCONFIG._serialized_end=543
  _PROJECTSOURCE._serialized_start=546
  _PROJECTSOURCE._serialized_end=987
  _PROJECTFILTERGROUP._serialized_start=989
  _PROJECTFILTERGROUP._serialized_end=1066
  _PROJECTPROJECTTRIGGERS._serialized_start=1069
  _PROJECTPROJECTTRIGGERS._serialized_end=1237
  _PROJECTARTIFACTS._serialized_start=1240
  _PROJECTARTIFACTS._serialized_end=1494
  _PROJECTCLOUDWATCHLOGSCONFIG._serialized_start=1497
  _PROJECTCLOUDWATCHLOGSCONFIG._serialized_end=1640
  _PROJECTS3LOGSCONFIG._serialized_start=1643
  _PROJECTS3LOGSCONFIG._serialized_end=1784
  _PROJECTLOGSCONFIG._serialized_start=1787
  _PROJECTLOGSCONFIG._serialized_end=2010
  _PROJECTPROJECTFILESYSTEMLOCATION._serialized_start=2013
  _PROJECTPROJECTFILESYSTEMLOCATION._serialized_end=2186
  _PROJECTENVIRONMENTVARIABLE._serialized_start=2188
  _PROJECTENVIRONMENTVARIABLE._serialized_end=2302
  _PROJECTREGISTRYCREDENTIAL._serialized_start=2305
  _PROJECTREGISTRYCREDENTIAL._serialized_end=2438
  _PROJECTENVIRONMENT._serialized_start=2441
  _PROJECTENVIRONMENT._serialized_end=2807
  _PROJECTPROJECTSOURCEVERSION._serialized_start=2810
  _PROJECTPROJECTSOURCEVERSION._serialized_end=2947
  _PROJECTBATCHRESTRICTIONS._serialized_start=2950
  _PROJECTBATCHRESTRICTIONS._serialized_end=3096
  _PROJECTPROJECTBUILDBATCHCONFIG._serialized_start=3099
  _PROJECTPROJECTBUILDBATCHCONFIG._serialized_end=3337
  _PROJECTPROJECTCACHE._serialized_start=3339
  _PROJECTPROJECTCACHE._serialized_end=3450
  _PROJECT._serialized_start=3453
  _PROJECT._serialized_end=4682
  _PROJECT_TAGSENTRY._serialized_start=4639
  _PROJECT_TAGSENTRY._serialized_end=4682
  _CODEBUILD._serialized_start=4685
  _CODEBUILD._serialized_end=4964
  _REPORTGROUPS3REPORTEXPORTCONFIG._serialized_start=4967
  _REPORTGROUPS3REPORTEXPORTCONFIG._serialized_end=5159
  _REPORTGROUPREPORTEXPORTCONFIG._serialized_start=5162
  _REPORTGROUPREPORTEXPORTCONFIG._serialized_end=5362
  _REPORTGROUP._serialized_start=5365
  _REPORTGROUP._serialized_end=5677
  _REPORTGROUP_TAGSENTRY._serialized_start=4639
  _REPORTGROUP_TAGSENTRY._serialized_end=4682
  _SOURCECREDENTIAL._serialized_start=5680
  _SOURCECREDENTIAL._serialized_end=5828
  _PROJECTWEBHOOKFILTER._serialized_start=5831
  _PROJECTWEBHOOKFILTER._serialized_end=5960
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ActivityTagsEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___ActivityTagsEntry = ActivityTagsEntry

@typing_extensions.final
class Activity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ARN_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    arn: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ActivityTagsEntry]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        arn: builtins.str = ...,
        tags: collections.abc.Iterable[global___ActivityTagsEntry] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arn", b"arn", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Activity = Activity

@typing_extensions.final
class StepFunctions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVITY_FIELD_NUMBER: builtins.int
    STATE_MACHINE_FIELD_NUMBER: builtins.int
    @property
    def activity(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Activity]: ...
    @property
    def state_machine(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StateMachine]: ...
    def __init__(
        self,
        *,
        activity: collections.abc.Iterable[global___Activity] | None = ...,
        state_machine: collections.abc.Iterable[global___StateMachine] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity", b"activity", "state_machine", b"state_machine"]) -> None: ...

global___StepFunctions = StepFunctions

@typing_extensions.final
class StateMachineCloudWatchLogsLogGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOG_GROUP_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    log_group_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        log_group_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["log_group_arn", b"log_group_arn", "resource_info", b"resource_info"]) -> None: ...

global___StateMachineCloudWatchLogsLogGroup = StateMachineCloudWatchLogsLogGroup

@typing_extensions.final
class StateMachineLogDestination(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_LOGS_LOG_GROUP_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def cloud_watch_logs_log_group(self) -> global___StateMachineCloudWatchLogsLogGroup: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cloud_watch_logs_log_group: global___StateMachineCloudWatchLogsLogGroup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_watch_logs_log_group", b"cloud_watch_logs_log_group", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_watch_logs_log_group", b"cloud_watch_logs_log_group", "resource_info", b"resource_info"]) -> None: ...

global___StateMachineLogDestination = StateMachineLogDestination

@typing_extensions.final
class StateMachineLoggingConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    INCLUDE_EXECUTION_DATA_FIELD_NUMBER: builtins.int
    DESTINATIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    level: builtins.str
    include_execution_data: builtins.bool
    @property
    def destinations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StateMachineLogDestination]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        level: builtins.str = ...,
        include_execution_data: builtins.bool = ...,
        destinations: collections.abc.Iterable[global___StateMachineLogDestination] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destinations", b"destinations", "include_execution_data", b"include_execution_data", "level", b"level", "resource_info", b"resource_info"]) -> None: ...

global___StateMachineLoggingConfiguration = StateMachineLoggingConfiguration

@typing_extensions.final
class StateMachineTracingConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "resource_info", b"resource_info"]) -> None: ...

global___StateMachineTracingConfiguration = StateMachineTracingConfiguration

@typing_extensions.final
class StateMachineS3Location(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bucket: builtins.str
    key: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bucket: builtins.str = ...,
        key: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "key", b"key", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___StateMachineS3Location = StateMachineS3Location

@typing_extensions.final
class StateMachineDefinitionSubstitutions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___StateMachineDefinitionSubstitutions = StateMachineDefinitionSubstitutions

@typing_extensions.final
class StateMachineTagsEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___StateMachineTagsEntry = StateMachineTagsEntry

@typing_extensions.final
class StateMachine(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEFINITION_STRING_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    STATE_MACHINE_NAME_FIELD_NUMBER: builtins.int
    STATE_MACHINE_TYPE_FIELD_NUMBER: builtins.int
    LOGGING_CONFIGURATION_FIELD_NUMBER: builtins.int
    TRACING_CONFIGURATION_FIELD_NUMBER: builtins.int
    DEFINITION_S3_LOCATION_FIELD_NUMBER: builtins.int
    DEFINITION_SUBSTITUTIONS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    definition_string: builtins.str
    role_arn: builtins.str
    state_machine_name: builtins.str
    state_machine_type: builtins.str
    @property
    def logging_configuration(self) -> global___StateMachineLoggingConfiguration: ...
    @property
    def tracing_configuration(self) -> global___StateMachineTracingConfiguration: ...
    @property
    def definition_s3_location(self) -> global___StateMachineS3Location: ...
    @property
    def definition_substitutions(self) -> global___StateMachineDefinitionSubstitutions: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StateMachineTagsEntry]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        definition_string: builtins.str = ...,
        role_arn: builtins.str = ...,
        state_machine_name: builtins.str = ...,
        state_machine_type: builtins.str = ...,
        logging_configuration: global___StateMachineLoggingConfiguration | None = ...,
        tracing_configuration: global___StateMachineTracingConfiguration | None = ...,
        definition_s3_location: global___StateMachineS3Location | None = ...,
        definition_substitutions: global___StateMachineDefinitionSubstitutions | None = ...,
        tags: collections.abc.Iterable[global___StateMachineTagsEntry] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["definition_s3_location", b"definition_s3_location", "definition_substitutions", b"definition_substitutions", "logging_configuration", b"logging_configuration", "resource_info", b"resource_info", "tracing_configuration", b"tracing_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["definition_s3_location", b"definition_s3_location", "definition_string", b"definition_string", "definition_substitutions", b"definition_substitutions", "logging_configuration", b"logging_configuration", "resource_info", b"resource_info", "role_arn", b"role_arn", "state_machine_name", b"state_machine_name", "state_machine_type", b"state_machine_type", "tags", b"tags", "tracing_configuration", b"tracing_configuration"]) -> None: ...

global___StateMachine = StateMachine



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_game.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12gcp/gcp_game.proto\x12\x14oak9.tython.gcp.game\x1a\x13shared/shared.proto\"S\n@GameServicesGameServerClusterXConnectionInfoXGkeClusterReference\x12\x0f\n\x07\x63luster\x18\x01 \x01(\t\"\xb8\x01\n,GameServicesGameServerClusterXConnectionInfo\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12u\n\x15gke_cluster_reference\x18\x02 \x01(\x0b\x32V.oak9.tython.gcp.game.GameServicesGameServerClusterXConnectionInfoXGkeClusterReference\"X\n&GameServicesGameServerClusterXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xfd\x03\n\x1dGameServicesGameServerCluster\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12O\n\x06labels\x18\x04 \x03(\x0b\x32?.oak9.tython.gcp.game.GameServicesGameServerCluster.LabelsEntry\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x10\n\x08realm_id\x18\x08 \x01(\t\x12[\n\x0f\x63onnection_info\x18\t \x01(\x0b\x32\x42.oak9.tython.gcp.game.GameServicesGameServerClusterXConnectionInfo\x12N\n\x08timeouts\x18\n \x01(\x0b\x32<.oak9.tython.gcp.game.GameServicesGameServerClusterXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"M\n)GameServicesGameServerConfigXFleetConfigs\x12\x12\n\nfleet_spec\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x8b\x01\n5GameServicesGameServerConfigXScalingConfigsXSchedules\x12\x19\n\x11\x63ron_job_duration\x18\x01 \x01(\t\x12\x11\n\tcron_spec\x18\x02 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x03 \x01(\t\x12\x12\n\nstart_time\x18\x04 \x01(\t\"\xcf\x01\n5GameServicesGameServerConfigXScalingConfigsXSelectors\x12g\n\x06labels\x18\x01 \x03(\x0b\x32W.oak9.tython.gcp.game.GameServicesGameServerConfigXScalingConfigsXSelectors.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x02\n+GameServicesGameServerConfigXScalingConfigs\x12\x1d\n\x15\x66leet_autoscaler_spec\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12^\n\tschedules\x18\x03 \x03(\x0b\x32K.oak9.tython.gcp.game.GameServicesGameServerConfigXScalingConfigsXSchedules\x12^\n\tselectors\x18\x04 \x03(\x0b\x32K.oak9.tython.gcp.game.GameServicesGameServerConfigXScalingConfigsXSelectors\"G\n%GameServicesGameServerConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xd5\x04\n\x1cGameServicesGameServerConfig\x12\x11\n\tconfig_id\x18\x01 \x01(\t\x12\x15\n\rdeployment_id\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12N\n\x06labels\x18\x05 \x03(\x0b\x32>.oak9.tython.gcp.game.GameServicesGameServerConfig.LabelsEntry\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12V\n\rfleet_configs\x18\t \x03(\x0b\x32?.oak9.tython.gcp.game.GameServicesGameServerConfigXFleetConfigs\x12Z\n\x0fscaling_configs\x18\n \x03(\x0b\x32\x41.oak9.tython.gcp.game.GameServicesGameServerConfigXScalingConfigs\x12M\n\x08timeouts\x18\x0b \x01(\x0b\x32;.oak9.tython.gcp.game.GameServicesGameServerConfigXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"[\n)GameServicesGameServerDeploymentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x9a\x03\n GameServicesGameServerDeployment\x12\x15\n\rdeployment_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12R\n\x06labels\x18\x04 \x03(\x0b\x32\x42.oak9.tython.gcp.game.GameServicesGameServerDeployment.LabelsEntry\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12Q\n\x08timeouts\x18\x08 \x01(\x0b\x32?.oak9.tython.gcp.game.GameServicesGameServerDeploymentXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\nPGameServicesGameServerDeploymentRolloutXGameServerConfigOverridesXRealmsSelector\x12\x0e\n\x06realms\x18\x01 \x03(\t\"\xdc\x01\nAGameServicesGameServerDeploymentRolloutXGameServerConfigOverrides\x12\x16\n\x0e\x63onfig_version\x18\x01 \x01(\t\x12\x7f\n\x0frealms_selector\x18\x02 \x01(\x0b\x32\x66.oak9.tython.gcp.game.GameServicesGameServerDeploymentRolloutXGameServerConfigOverridesXRealmsSelector\"b\n0GameServicesGameServerDeploymentRolloutXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa1\x03\n\'GameServicesGameServerDeploymentRollout\x12\"\n\x1a\x64\x65\x66\x61ult_game_server_config\x18\x01 \x01(\t\x12\x15\n\rdeployment_id\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12}\n\x1cgame_server_config_overrides\x18\x06 \x03(\x0b\x32W.oak9.tython.gcp.game.GameServicesGameServerDeploymentRolloutXGameServerConfigOverrides\x12X\n\x08timeouts\x18\x07 \x01(\x0b\x32\x46.oak9.tython.gcp.game.GameServicesGameServerDeploymentRolloutXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"L\n\x1aGameServicesRealmXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x89\x03\n\x11GameServicesRealm\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x43\n\x06labels\x18\x04 \x03(\x0b\x32\x33.oak9.tython.gcp.game.GameServicesRealm.LabelsEntry\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x10\n\x08realm_id\x18\x08 \x01(\t\x12\x11\n\ttime_zone\x18\t \x01(\t\x12\x42\n\x08timeouts\x18\n \x01(\x0b\x32\x30.oak9.tython.gcp.game.GameServicesRealmXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_game_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GAMESERVICESGAMESERVERCLUSTER_LABELSENTRY._options = None
  _GAMESERVICESGAMESERVERCLUSTER_LABELSENTRY._serialized_options = b'8\001'
  _GAMESERVICESGAMESERVERCONFIGXSCALINGCONFIGSXSELECTORS_LABELSENTRY._options = None
  _GAMESERVICESGAMESERVERCONFIGXSCALINGCONFIGSXSELECTORS_LABELSENTRY._serialized_options = b'8\001'
  _GAMESERVICESGAMESERVERCONFIG_LABELSENTRY._options = None
  _GAMESERVICESGAMESERVERCONFIG_LABELSENTRY._serialized_options = b'8\001'
  _GAMESERVICESGAMESERVERDEPLOYMENT_LABELSENTRY._options = None
  _GAMESERVICESGAMESERVERDEPLOYMENT_LABELSENTRY._serialized_options = b'8\001'
  _GAMESERVICESREALM_LABELSENTRY._options = None
  _GAMESERVICESREALM_LABELSENTRY._serialized_options = b'8\001'
  _GAMESERVICESGAMESERVERCLUSTERXCONNECTIONINFOXGKECLUSTERREFERENCE._serialized_start=65
  _GAMESERVICESGAMESERVERCLUSTERXCONNECTIONINFOXGKECLUSTERREFERENCE._serialized_end=148
  _GAMESERVICESGAMESERVERCLUSTERXCONNECTIONINFO._serialized_start=151
  _GAMESERVICESGAMESERVERCLUSTERXCONNECTIONINFO._serialized_end=335
  _GAMESERVICESGAMESERVERCLUSTERXTIMEOUTS._serialized_start=337
  _GAMESERVICESGAMESERVERCLUSTERXTIMEOUTS._serialized_end=425
  _GAMESERVICESGAMESERVERCLUSTER._serialized_start=428
  _GAMESERVICESGAMESERVERCLUSTER._serialized_end=937
  _GAMESERVICESGAMESERVERCLUSTER_LABELSENTRY._serialized_start=892
  _GAMESERVICESGAMESERVERCLUSTER_LABELSENTRY._serialized_end=937
  _GAMESERVICESGAMESERVERCONFIGXFLEETCONFIGS._serialized_start=939
  _GAMESERVICESGAMESERVERCONFIGXFLEETCONFIGS._serialized_end=1016
  _GAMESERVICESGAMESERVERCONFIGXSCALINGCONFIGSXSCHEDULES._serialized_start=1019
  _GAMESERVICESGAMESERVERCONFIGXSCALINGCONFIGSXSCHEDULES._serialized_end=1158
  _GAMESERVICESGAMESERVERCONFIGXSCALINGCONFIGSXSELECTORS._serialized_start=1161
  _GAMESERVICESGAMESERVERCONFIGXSCALINGCONFIGSXSELECTORS._serialized_end=1368
  _GAMESERVICESGAMESERVERCONFIGXSCALINGCONFIGSXSELECTORS_LABELSENTRY._serialized_start=892
  _GAMESERVICESGAMESERVERCONFIGXSCALINGCONFIGSXSELECTORS_LABELSENTRY._serialized_end=937
  _GAMESERVICESGAMESERVERCONFIGXSCALINGCONFIGS._serialized_start=1371
  _GAMESERVICESGAMESERVERCONFIGXSCALINGCONFIGS._serialized_end=1653
  _GAMESERVICESGAMESERVERCONFIGXTIMEOUTS._serialized_start=1655
  _GAMESERVICESGAMESERVERCONFIGXTIMEOUTS._serialized_end=1726
  _GAMESERVICESGAMESERVERCONFIG._serialized_start=1729
  _GAMESERVICESGAMESERVERCONFIG._serialized_end=2326
  _GAMESERVICESGAMESERVERCONFIG_LABELSENTRY._serialized_start=892
  _GAMESERVICESGAMESERVERCONFIG_LABELSENTRY._serialized_end=937
  _GAMESERVICESGAMESERVERDEPLOYMENTXTIMEOUTS._serialized_start=2328
  _GAMESERVICESGAMESERVERDEPLOYMENTXTIMEOUTS._serialized_end=2419
  _GAMESERVICESGAMESERVERDEPLOYMENT._serialized_start=2422
  _GAMESERVICESGAMESERVERDEPLOYMENT._serialized_end=2832
  _GAMESERVICESGAMESERVERDEPLOYMENT_LABELSENTRY._serialized_start=892
  _GAMESERVICESGAMESERVERDEPLOYMENT_LABELSENTRY._serialized_end=937
  _GAMESERVICESGAMESERVERDEPLOYMENTROLLOUTXGAMESERVERCONFIGOVERRIDESXREALMSSELECTOR._serialized_start=2834
  _GAMESERVICESGAMESERVERDEPLOYMENTROLLOUTXGAMESERVERCONFIGOVERRIDESXREALMSSELECTOR._serialized_end=2932
  _GAMESERVICESGAMESERVERDEPLOYMENTROLLOUTXGAMESERVERCONFIGOVERRIDES._serialized_start=2935
  _GAMESERVICESGAMESERVERDEPLOYMENTROLLOUTXGAMESERVERCONFIGOVERRIDES._serialized_end=3155
  _GAMESERVICESGAMESERVERDEPLOYMENTROLLOUTXTIMEOUTS._serialized_start=3157
  _GAMESERVICESGAMESERVERDEPLOYMENTROLLOUTXTIMEOUTS._serialized_end=3255
  _GAMESERVICESGAMESERVERDEPLOYMENTROLLOUT._serialized_start=3258
  _GAMESERVICESGAMESERVERDEPLOYMENTROLLOUT._serialized_end=3675
  _GAMESERVICESREALMXTIMEOUTS._serialized_start=3677
  _GAMESERVICESREALMXTIMEOUTS._serialized_end=3753
  _GAMESERVICESREALM._serialized_start=3756
  _GAMESERVICESREALM._serialized_end=4149
  _GAMESERVICESREALM_LABELSENTRY._serialized_start=892
  _GAMESERVICESREALM_LABELSENTRY._serialized_end=937
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Config(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ConfigDataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    CONFIG_DATA_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def config_data(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        config_data: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_data", b"config_data", "name", b"name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Config = Config

@typing_extensions.final
class GroundStation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    DATAFLOW_ENDPOINT_GROUP_FIELD_NUMBER: builtins.int
    MISSION_PROFILE_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Config]: ...
    @property
    def dataflow_endpoint_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataflowEndpointGroup]: ...
    @property
    def mission_profile(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MissionProfile]: ...
    def __init__(
        self,
        *,
        config: collections.abc.Iterable[global___Config] | None = ...,
        dataflow_endpoint_group: collections.abc.Iterable[global___DataflowEndpointGroup] | None = ...,
        mission_profile: collections.abc.Iterable[global___MissionProfile] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "dataflow_endpoint_group", b"dataflow_endpoint_group", "mission_profile", b"mission_profile"]) -> None: ...

global___GroundStation = GroundStation

@typing_extensions.final
class DataflowEndpointGroupSecurityDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "role_arn", b"role_arn", "security_group_ids", b"security_group_ids", "subnet_ids", b"subnet_ids"]) -> None: ...

global___DataflowEndpointGroupSecurityDetails = DataflowEndpointGroupSecurityDetails

@typing_extensions.final
class DataflowEndpointGroupSocketAddress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    port: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        port: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "port", b"port", "resource_info", b"resource_info"]) -> None: ...

global___DataflowEndpointGroupSocketAddress = DataflowEndpointGroupSocketAddress

@typing_extensions.final
class DataflowEndpointGroupDataflowEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    MTU_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def address(self) -> global___DataflowEndpointGroupSocketAddress: ...
    status: builtins.str
    mtu: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        address: global___DataflowEndpointGroupSocketAddress | None = ...,
        status: builtins.str = ...,
        mtu: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["address", b"address", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "mtu", b"mtu", "name", b"name", "resource_info", b"resource_info", "status", b"status"]) -> None: ...

global___DataflowEndpointGroupDataflowEndpoint = DataflowEndpointGroupDataflowEndpoint

@typing_extensions.final
class DataflowEndpointGroupEndpointDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SECURITY_DETAILS_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def security_details(self) -> global___DataflowEndpointGroupSecurityDetails: ...
    @property
    def endpoint(self) -> global___DataflowEndpointGroupDataflowEndpoint: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        security_details: global___DataflowEndpointGroupSecurityDetails | None = ...,
        endpoint: global___DataflowEndpointGroupDataflowEndpoint | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["endpoint", b"endpoint", "resource_info", b"resource_info", "security_details", b"security_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint", b"endpoint", "resource_info", b"resource_info", "security_details", b"security_details"]) -> None: ...

global___DataflowEndpointGroupEndpointDetails = DataflowEndpointGroupEndpointDetails

@typing_extensions.final
class DataflowEndpointGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENDPOINT_DETAILS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def endpoint_details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataflowEndpointGroupEndpointDetails]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        endpoint_details: collections.abc.Iterable[global___DataflowEndpointGroupEndpointDetails] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint_details", b"endpoint_details", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DataflowEndpointGroup = DataflowEndpointGroup

@typing_extensions.final
class MissionProfileDataflowEdge(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    source: builtins.str
    destination: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        source: builtins.str = ...,
        destination: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination", b"destination", "resource_info", b"resource_info", "source", b"source"]) -> None: ...

global___MissionProfileDataflowEdge = MissionProfileDataflowEdge

@typing_extensions.final
class MissionProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONTACT_PRE_PASS_DURATION_SECONDS_FIELD_NUMBER: builtins.int
    CONTACT_POST_PASS_DURATION_SECONDS_FIELD_NUMBER: builtins.int
    MINIMUM_VIABLE_CONTACT_DURATION_SECONDS_FIELD_NUMBER: builtins.int
    DATAFLOW_EDGES_FIELD_NUMBER: builtins.int
    TRACKING_CONFIG_ARN_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    contact_pre_pass_duration_seconds: builtins.int
    contact_post_pass_duration_seconds: builtins.int
    minimum_viable_contact_duration_seconds: builtins.int
    @property
    def dataflow_edges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MissionProfileDataflowEdge]: ...
    tracking_config_arn: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        contact_pre_pass_duration_seconds: builtins.int = ...,
        contact_post_pass_duration_seconds: builtins.int = ...,
        minimum_viable_contact_duration_seconds: builtins.int = ...,
        dataflow_edges: collections.abc.Iterable[global___MissionProfileDataflowEdge] | None = ...,
        tracking_config_arn: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["contact_post_pass_duration_seconds", b"contact_post_pass_duration_seconds", "contact_pre_pass_duration_seconds", b"contact_pre_pass_duration_seconds", "dataflow_edges", b"dataflow_edges", "minimum_viable_contact_duration_seconds", b"minimum_viable_contact_duration_seconds", "name", b"name", "resource_info", b"resource_info", "tags", b"tags", "tracking_config_arn", b"tracking_config_arn"]) -> None: ...

global___MissionProfile = MissionProfile



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class StreamStreamEncryption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENCRYPTION_TYPE_FIELD_NUMBER: builtins.int
    KEY_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    encryption_type: builtins.str
    key_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        encryption_type: builtins.str = ...,
        key_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["encryption_type", b"encryption_type", "key_id", b"key_id", "resource_info", b"resource_info"]) -> None: ...

global___StreamStreamEncryption = StreamStreamEncryption

@typing_extensions.final
class Stream(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RETENTION_PERIOD_HOURS_FIELD_NUMBER: builtins.int
    SHARD_COUNT_FIELD_NUMBER: builtins.int
    STREAM_ENCRYPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    retention_period_hours: builtins.int
    shard_count: builtins.int
    @property
    def stream_encryption(self) -> global___StreamStreamEncryption: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        retention_period_hours: builtins.int = ...,
        shard_count: builtins.int = ...,
        stream_encryption: global___StreamStreamEncryption | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "stream_encryption", b"stream_encryption"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "retention_period_hours", b"retention_period_hours", "shard_count", b"shard_count", "stream_encryption", b"stream_encryption", "tags", b"tags"]) -> None: ...

global___Stream = Stream

@typing_extensions.final
class Kinesis(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_FIELD_NUMBER: builtins.int
    @property
    def stream(self) -> global___Stream: ...
    def __init__(
        self,
        *,
        stream: global___Stream | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["stream", b"stream"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["stream", b"stream"]) -> None: ...

global___Kinesis = Kinesis

@typing_extensions.final
class StreamConsumer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONSUMER_NAME_FIELD_NUMBER: builtins.int
    STREAM_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    consumer_name: builtins.str
    stream_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        consumer_name: builtins.str = ...,
        stream_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["consumer_name", b"consumer_name", "resource_info", b"resource_info", "stream_arn", b"stream_arn"]) -> None: ...

global___StreamConsumer = StreamConsumer



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ApiBodyS3Location(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    etag: builtins.str
    bucket: builtins.str
    version: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        etag: builtins.str = ...,
        bucket: builtins.str = ...,
        version: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "etag", b"etag", "key", b"key", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___ApiBodyS3Location = ApiBodyS3Location

@typing_extensions.final
class ApiCors(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALLOW_ORIGINS_FIELD_NUMBER: builtins.int
    ALLOW_CREDENTIALS_FIELD_NUMBER: builtins.int
    EXPOSE_HEADERS_FIELD_NUMBER: builtins.int
    ALLOW_HEADERS_FIELD_NUMBER: builtins.int
    MAX_AGE_FIELD_NUMBER: builtins.int
    ALLOW_METHODS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def allow_origins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    allow_credentials: builtins.bool
    @property
    def expose_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    max_age: builtins.int
    @property
    def allow_methods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        allow_origins: collections.abc.Iterable[builtins.str] | None = ...,
        allow_credentials: builtins.bool = ...,
        expose_headers: collections.abc.Iterable[builtins.str] | None = ...,
        allow_headers: collections.abc.Iterable[builtins.str] | None = ...,
        max_age: builtins.int = ...,
        allow_methods: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_credentials", b"allow_credentials", "allow_headers", b"allow_headers", "allow_methods", b"allow_methods", "allow_origins", b"allow_origins", "expose_headers", b"expose_headers", "max_age", b"max_age", "resource_info", b"resource_info"]) -> None: ...

global___ApiCors = ApiCors

@typing_extensions.final
class Api(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class BodyEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ROUTE_SELECTION_EXPRESSION_FIELD_NUMBER: builtins.int
    BODY_S3_LOCATION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    BASE_PATH_FIELD_NUMBER: builtins.int
    FAIL_ON_WARNINGS_FIELD_NUMBER: builtins.int
    DISABLE_EXECUTE_API_ENDPOINT_FIELD_NUMBER: builtins.int
    DISABLE_SCHEMA_VALIDATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    CREDENTIALS_ARN_FIELD_NUMBER: builtins.int
    CORS_CONFIGURATION_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    PROTOCOL_TYPE_FIELD_NUMBER: builtins.int
    ROUTE_KEY_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    API_KEY_SELECTION_EXPRESSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    route_selection_expression: builtins.str
    @property
    def body_s3_location(self) -> global___ApiBodyS3Location: ...
    description: builtins.str
    base_path: builtins.str
    fail_on_warnings: builtins.bool
    disable_execute_api_endpoint: builtins.bool
    disable_schema_validation: builtins.bool
    name: builtins.str
    target: builtins.str
    credentials_arn: builtins.str
    @property
    def cors_configuration(self) -> global___ApiCors: ...
    version: builtins.str
    protocol_type: builtins.str
    route_key: builtins.str
    @property
    def body(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    api_key_selection_expression: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        route_selection_expression: builtins.str = ...,
        body_s3_location: global___ApiBodyS3Location | None = ...,
        description: builtins.str = ...,
        base_path: builtins.str = ...,
        fail_on_warnings: builtins.bool = ...,
        disable_execute_api_endpoint: builtins.bool = ...,
        disable_schema_validation: builtins.bool = ...,
        name: builtins.str = ...,
        target: builtins.str = ...,
        credentials_arn: builtins.str = ...,
        cors_configuration: global___ApiCors | None = ...,
        version: builtins.str = ...,
        protocol_type: builtins.str = ...,
        route_key: builtins.str = ...,
        body: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        api_key_selection_expression: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["body_s3_location", b"body_s3_location", "cors_configuration", b"cors_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_key_selection_expression", b"api_key_selection_expression", "base_path", b"base_path", "body", b"body", "body_s3_location", b"body_s3_location", "cors_configuration", b"cors_configuration", "credentials_arn", b"credentials_arn", "description", b"description", "disable_execute_api_endpoint", b"disable_execute_api_endpoint", "disable_schema_validation", b"disable_schema_validation", "fail_on_warnings", b"fail_on_warnings", "name", b"name", "protocol_type", b"protocol_type", "resource_info", b"resource_info", "route_key", b"route_key", "route_selection_expression", b"route_selection_expression", "tags", b"tags", "target", b"target", "version", b"version"]) -> None: ...

global___Api = Api

@typing_extensions.final
class ApiGatewayV2(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_FIELD_NUMBER: builtins.int
    API_MAPPING_FIELD_NUMBER: builtins.int
    AUTHORIZER_FIELD_NUMBER: builtins.int
    DEPLOYMENT_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    INTEGRATION_FIELD_NUMBER: builtins.int
    INTEGRATION_RESPONSE_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    ROUTE_FIELD_NUMBER: builtins.int
    ROUTE_RESPONSE_FIELD_NUMBER: builtins.int
    STAGE_FIELD_NUMBER: builtins.int
    @property
    def api(self) -> global___Api: ...
    @property
    def api_mapping(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApiMapping]: ...
    @property
    def authorizer(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Authorizer]: ...
    @property
    def deployment(self) -> global___Deployment: ...
    @property
    def domain_name(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DomainName]: ...
    @property
    def integration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Integration]: ...
    @property
    def integration_response(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IntegrationResponse]: ...
    @property
    def model(self) -> global___Model: ...
    @property
    def route(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Route]: ...
    @property
    def route_response(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RouteResponse]: ...
    @property
    def stage(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Stage]: ...
    def __init__(
        self,
        *,
        api: global___Api | None = ...,
        api_mapping: collections.abc.Iterable[global___ApiMapping] | None = ...,
        authorizer: collections.abc.Iterable[global___Authorizer] | None = ...,
        deployment: global___Deployment | None = ...,
        domain_name: collections.abc.Iterable[global___DomainName] | None = ...,
        integration: collections.abc.Iterable[global___Integration] | None = ...,
        integration_response: collections.abc.Iterable[global___IntegrationResponse] | None = ...,
        model: global___Model | None = ...,
        route: collections.abc.Iterable[global___Route] | None = ...,
        route_response: collections.abc.Iterable[global___RouteResponse] | None = ...,
        stage: collections.abc.Iterable[global___Stage] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["api", b"api", "deployment", b"deployment", "model", b"model"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api", b"api", "api_mapping", b"api_mapping", "authorizer", b"authorizer", "deployment", b"deployment", "domain_name", b"domain_name", "integration", b"integration", "integration_response", b"integration_response", "model", b"model", "route", b"route", "route_response", b"route_response", "stage", b"stage"]) -> None: ...

global___ApiGatewayV2 = ApiGatewayV2

@typing_extensions.final
class ApiMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    STAGE_FIELD_NUMBER: builtins.int
    API_MAPPING_KEY_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    domain_name: builtins.str
    stage: builtins.str
    api_mapping_key: builtins.str
    api_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        domain_name: builtins.str = ...,
        stage: builtins.str = ...,
        api_mapping_key: builtins.str = ...,
        api_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "api_mapping_key", b"api_mapping_key", "domain_name", b"domain_name", "resource_info", b"resource_info", "stage", b"stage"]) -> None: ...

global___ApiMapping = ApiMapping

@typing_extensions.final
class AuthorizerJWTConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    AUDIENCE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    issuer: builtins.str
    @property
    def audience(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        issuer: builtins.str = ...,
        audience: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience", b"audience", "issuer", b"issuer", "resource_info", b"resource_info"]) -> None: ...

global___AuthorizerJWTConfiguration = AuthorizerJWTConfiguration

@typing_extensions.final
class Authorizer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_VALIDATION_EXPRESSION_FIELD_NUMBER: builtins.int
    AUTHORIZER_URI_FIELD_NUMBER: builtins.int
    AUTHORIZER_CREDENTIALS_ARN_FIELD_NUMBER: builtins.int
    AUTHORIZER_TYPE_FIELD_NUMBER: builtins.int
    JWT_CONFIGURATION_FIELD_NUMBER: builtins.int
    AUTHORIZER_RESULT_TTL_IN_SECONDS_FIELD_NUMBER: builtins.int
    IDENTITY_SOURCE_FIELD_NUMBER: builtins.int
    AUTHORIZER_PAYLOAD_FORMAT_VERSION_FIELD_NUMBER: builtins.int
    ENABLE_SIMPLE_RESPONSES_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    identity_validation_expression: builtins.str
    authorizer_uri: builtins.str
    authorizer_credentials_arn: builtins.str
    authorizer_type: builtins.str
    @property
    def jwt_configuration(self) -> global___AuthorizerJWTConfiguration: ...
    authorizer_result_ttl_in_seconds: builtins.int
    @property
    def identity_source(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    authorizer_payload_format_version: builtins.str
    enable_simple_responses: builtins.bool
    api_id: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity_validation_expression: builtins.str = ...,
        authorizer_uri: builtins.str = ...,
        authorizer_credentials_arn: builtins.str = ...,
        authorizer_type: builtins.str = ...,
        jwt_configuration: global___AuthorizerJWTConfiguration | None = ...,
        authorizer_result_ttl_in_seconds: builtins.int = ...,
        identity_source: collections.abc.Iterable[builtins.str] | None = ...,
        authorizer_payload_format_version: builtins.str = ...,
        enable_simple_responses: builtins.bool = ...,
        api_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["jwt_configuration", b"jwt_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "authorizer_credentials_arn", b"authorizer_credentials_arn", "authorizer_payload_format_version", b"authorizer_payload_format_version", "authorizer_result_ttl_in_seconds", b"authorizer_result_ttl_in_seconds", "authorizer_type", b"authorizer_type", "authorizer_uri", b"authorizer_uri", "enable_simple_responses", b"enable_simple_responses", "identity_source", b"identity_source", "identity_validation_expression", b"identity_validation_expression", "jwt_configuration", b"jwt_configuration", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___Authorizer = Authorizer

@typing_extensions.final
class Deployment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STAGE_NAME_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    stage_name: builtins.str
    api_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        stage_name: builtins.str = ...,
        api_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "description", b"description", "resource_info", b"resource_info", "stage_name", b"stage_name"]) -> None: ...

global___Deployment = Deployment

@typing_extensions.final
class DomainNameMutualTlsAuthentication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TRUSTSTORE_VERSION_FIELD_NUMBER: builtins.int
    TRUSTSTORE_URI_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    truststore_version: builtins.str
    truststore_uri: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        truststore_version: builtins.str = ...,
        truststore_uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "truststore_uri", b"truststore_uri", "truststore_version", b"truststore_version"]) -> None: ...

global___DomainNameMutualTlsAuthentication = DomainNameMutualTlsAuthentication

@typing_extensions.final
class DomainNameDomainNameConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SECURITY_POLICY_FIELD_NUMBER: builtins.int
    ENDPOINT_TYPE_FIELD_NUMBER: builtins.int
    CERTIFICATE_NAME_FIELD_NUMBER: builtins.int
    CERTIFICATE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    security_policy: builtins.str
    endpoint_type: builtins.str
    certificate_name: builtins.str
    certificate_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        security_policy: builtins.str = ...,
        endpoint_type: builtins.str = ...,
        certificate_name: builtins.str = ...,
        certificate_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_arn", b"certificate_arn", "certificate_name", b"certificate_name", "endpoint_type", b"endpoint_type", "resource_info", b"resource_info", "security_policy", b"security_policy"]) -> None: ...

global___DomainNameDomainNameConfiguration = DomainNameDomainNameConfiguration

@typing_extensions.final
class DomainName(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MUTUAL_TLS_AUTHENTICATION_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def mutual_tls_authentication(self) -> global___DomainNameMutualTlsAuthentication: ...
    domain_name: builtins.str
    @property
    def domain_name_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DomainNameDomainNameConfiguration]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        mutual_tls_authentication: global___DomainNameMutualTlsAuthentication | None = ...,
        domain_name: builtins.str = ...,
        domain_name_configurations: collections.abc.Iterable[global___DomainNameDomainNameConfiguration] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["mutual_tls_authentication", b"mutual_tls_authentication", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain_name", b"domain_name", "domain_name_configurations", b"domain_name_configurations", "mutual_tls_authentication", b"mutual_tls_authentication", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DomainName = DomainName

@typing_extensions.final
class IntegrationTlsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SERVER_NAME_TO_VERIFY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    server_name_to_verify: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        server_name_to_verify: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "server_name_to_verify", b"server_name_to_verify"]) -> None: ...

global___IntegrationTlsConfig = IntegrationTlsConfig

@typing_extensions.final
class Integration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class RequestParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class RequestTemplatesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TEMPLATE_SELECTION_EXPRESSION_FIELD_NUMBER: builtins.int
    CONNECTION_TYPE_FIELD_NUMBER: builtins.int
    INTEGRATION_METHOD_FIELD_NUMBER: builtins.int
    PASSTHROUGH_BEHAVIOR_FIELD_NUMBER: builtins.int
    REQUEST_PARAMETERS_FIELD_NUMBER: builtins.int
    CONNECTION_ID_FIELD_NUMBER: builtins.int
    INTEGRATION_URI_FIELD_NUMBER: builtins.int
    PAYLOAD_FORMAT_VERSION_FIELD_NUMBER: builtins.int
    CREDENTIALS_ARN_FIELD_NUMBER: builtins.int
    REQUEST_TEMPLATES_FIELD_NUMBER: builtins.int
    TIMEOUT_IN_MILLIS_FIELD_NUMBER: builtins.int
    TLS_CONFIG_FIELD_NUMBER: builtins.int
    CONTENT_HANDLING_STRATEGY_FIELD_NUMBER: builtins.int
    INTEGRATION_SUBTYPE_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    INTEGRATION_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    template_selection_expression: builtins.str
    connection_type: builtins.str
    integration_method: builtins.str
    passthrough_behavior: builtins.str
    @property
    def request_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    connection_id: builtins.str
    integration_uri: builtins.str
    payload_format_version: builtins.str
    credentials_arn: builtins.str
    @property
    def request_templates(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    timeout_in_millis: builtins.int
    @property
    def tls_config(self) -> global___IntegrationTlsConfig: ...
    content_handling_strategy: builtins.str
    integration_subtype: builtins.str
    api_id: builtins.str
    integration_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        template_selection_expression: builtins.str = ...,
        connection_type: builtins.str = ...,
        integration_method: builtins.str = ...,
        passthrough_behavior: builtins.str = ...,
        request_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        connection_id: builtins.str = ...,
        integration_uri: builtins.str = ...,
        payload_format_version: builtins.str = ...,
        credentials_arn: builtins.str = ...,
        request_templates: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        timeout_in_millis: builtins.int = ...,
        tls_config: global___IntegrationTlsConfig | None = ...,
        content_handling_strategy: builtins.str = ...,
        integration_subtype: builtins.str = ...,
        api_id: builtins.str = ...,
        integration_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "tls_config", b"tls_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "connection_id", b"connection_id", "connection_type", b"connection_type", "content_handling_strategy", b"content_handling_strategy", "credentials_arn", b"credentials_arn", "description", b"description", "integration_method", b"integration_method", "integration_subtype", b"integration_subtype", "integration_type", b"integration_type", "integration_uri", b"integration_uri", "passthrough_behavior", b"passthrough_behavior", "payload_format_version", b"payload_format_version", "request_parameters", b"request_parameters", "request_templates", b"request_templates", "resource_info", b"resource_info", "template_selection_expression", b"template_selection_expression", "timeout_in_millis", b"timeout_in_millis", "tls_config", b"tls_config"]) -> None: ...

global___Integration = Integration

@typing_extensions.final
class IntegrationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ResponseTemplatesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ResponseParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESPONSE_TEMPLATES_FIELD_NUMBER: builtins.int
    TEMPLATE_SELECTION_EXPRESSION_FIELD_NUMBER: builtins.int
    RESPONSE_PARAMETERS_FIELD_NUMBER: builtins.int
    CONTENT_HANDLING_STRATEGY_FIELD_NUMBER: builtins.int
    INTEGRATION_ID_FIELD_NUMBER: builtins.int
    INTEGRATION_RESPONSE_KEY_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def response_templates(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    template_selection_expression: builtins.str
    @property
    def response_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    content_handling_strategy: builtins.str
    integration_id: builtins.str
    integration_response_key: builtins.str
    api_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        response_templates: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        template_selection_expression: builtins.str = ...,
        response_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        content_handling_strategy: builtins.str = ...,
        integration_id: builtins.str = ...,
        integration_response_key: builtins.str = ...,
        api_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "content_handling_strategy", b"content_handling_strategy", "integration_id", b"integration_id", "integration_response_key", b"integration_response_key", "resource_info", b"resource_info", "response_parameters", b"response_parameters", "response_templates", b"response_templates", "template_selection_expression", b"template_selection_expression"]) -> None: ...

global___IntegrationResponse = IntegrationResponse

@typing_extensions.final
class Model(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SchemaEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    content_type: builtins.str
    @property
    def schema(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    api_id: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        content_type: builtins.str = ...,
        schema: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        api_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "content_type", b"content_type", "description", b"description", "name", b"name", "resource_info", b"resource_info", "schema", b"schema"]) -> None: ...

global___Model = Model

@typing_extensions.final
class Route(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class RequestModelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class RequestParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    ROUTE_RESPONSE_SELECTION_EXPRESSION_FIELD_NUMBER: builtins.int
    AUTHORIZER_ID_FIELD_NUMBER: builtins.int
    REQUEST_MODELS_FIELD_NUMBER: builtins.int
    OPERATION_NAME_FIELD_NUMBER: builtins.int
    AUTHORIZATION_SCOPES_FIELD_NUMBER: builtins.int
    API_KEY_REQUIRED_FIELD_NUMBER: builtins.int
    ROUTE_KEY_FIELD_NUMBER: builtins.int
    AUTHORIZATION_TYPE_FIELD_NUMBER: builtins.int
    MODEL_SELECTION_EXPRESSION_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    REQUEST_PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    target: builtins.str
    route_response_selection_expression: builtins.str
    authorizer_id: builtins.str
    @property
    def request_models(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    operation_name: builtins.str
    @property
    def authorization_scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    api_key_required: builtins.bool
    route_key: builtins.str
    authorization_type: builtins.str
    model_selection_expression: builtins.str
    api_id: builtins.str
    @property
    def request_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        target: builtins.str = ...,
        route_response_selection_expression: builtins.str = ...,
        authorizer_id: builtins.str = ...,
        request_models: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        operation_name: builtins.str = ...,
        authorization_scopes: collections.abc.Iterable[builtins.str] | None = ...,
        api_key_required: builtins.bool = ...,
        route_key: builtins.str = ...,
        authorization_type: builtins.str = ...,
        model_selection_expression: builtins.str = ...,
        api_id: builtins.str = ...,
        request_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "api_key_required", b"api_key_required", "authorization_scopes", b"authorization_scopes", "authorization_type", b"authorization_type", "authorizer_id", b"authorizer_id", "model_selection_expression", b"model_selection_expression", "operation_name", b"operation_name", "request_models", b"request_models", "request_parameters", b"request_parameters", "resource_info", b"resource_info", "route_key", b"route_key", "route_response_selection_expression", b"route_response_selection_expression", "target", b"target"]) -> None: ...

global___Route = Route

@typing_extensions.final
class RouteResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ResponseParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ResponseModelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ROUTE_RESPONSE_KEY_FIELD_NUMBER: builtins.int
    RESPONSE_PARAMETERS_FIELD_NUMBER: builtins.int
    ROUTE_ID_FIELD_NUMBER: builtins.int
    MODEL_SELECTION_EXPRESSION_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    RESPONSE_MODELS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    route_response_key: builtins.str
    @property
    def response_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    route_id: builtins.str
    model_selection_expression: builtins.str
    api_id: builtins.str
    @property
    def response_models(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        route_response_key: builtins.str = ...,
        response_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        route_id: builtins.str = ...,
        model_selection_expression: builtins.str = ...,
        api_id: builtins.str = ...,
        response_models: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "model_selection_expression", b"model_selection_expression", "resource_info", b"resource_info", "response_models", b"response_models", "response_parameters", b"response_parameters", "route_id", b"route_id", "route_response_key", b"route_response_key"]) -> None: ...

global___RouteResponse = RouteResponse

@typing_extensions.final
class StageAccessLogSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    DESTINATION_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    format: builtins.str
    destination_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        format: builtins.str = ...,
        destination_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination_arn", b"destination_arn", "format", b"format", "resource_info", b"resource_info"]) -> None: ...

global___StageAccessLogSettings = StageAccessLogSettings

@typing_extensions.final
class StageRouteSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOGGING_LEVEL_FIELD_NUMBER: builtins.int
    DATA_TRACE_ENABLED_FIELD_NUMBER: builtins.int
    THROTTLING_BURST_LIMIT_FIELD_NUMBER: builtins.int
    DETAILED_METRICS_ENABLED_FIELD_NUMBER: builtins.int
    THROTTLING_RATE_LIMIT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    logging_level: builtins.str
    data_trace_enabled: builtins.bool
    throttling_burst_limit: builtins.int
    detailed_metrics_enabled: builtins.bool
    throttling_rate_limit: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        logging_level: builtins.str = ...,
        data_trace_enabled: builtins.bool = ...,
        throttling_burst_limit: builtins.int = ...,
        detailed_metrics_enabled: builtins.bool = ...,
        throttling_rate_limit: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_trace_enabled", b"data_trace_enabled", "detailed_metrics_enabled", b"detailed_metrics_enabled", "logging_level", b"logging_level", "resource_info", b"resource_info", "throttling_burst_limit", b"throttling_burst_limit", "throttling_rate_limit", b"throttling_rate_limit"]) -> None: ...

global___StageRouteSettings = StageRouteSettings

@typing_extensions.final
class Stage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class RouteSettingsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class StageVariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLIENT_CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ACCESS_LOG_SETTINGS_FIELD_NUMBER: builtins.int
    AUTO_DEPLOY_FIELD_NUMBER: builtins.int
    ROUTE_SETTINGS_FIELD_NUMBER: builtins.int
    STAGE_NAME_FIELD_NUMBER: builtins.int
    STAGE_VARIABLES_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    DEFAULT_ROUTE_SETTINGS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    client_certificate_id: builtins.str
    deployment_id: builtins.str
    description: builtins.str
    @property
    def access_log_settings(self) -> global___StageAccessLogSettings: ...
    auto_deploy: builtins.bool
    @property
    def route_settings(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    stage_name: builtins.str
    @property
    def stage_variables(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    api_id: builtins.str
    @property
    def default_route_settings(self) -> global___StageRouteSettings: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        client_certificate_id: builtins.str = ...,
        deployment_id: builtins.str = ...,
        description: builtins.str = ...,
        access_log_settings: global___StageAccessLogSettings | None = ...,
        auto_deploy: builtins.bool = ...,
        route_settings: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        stage_name: builtins.str = ...,
        stage_variables: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        api_id: builtins.str = ...,
        default_route_settings: global___StageRouteSettings | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["access_log_settings", b"access_log_settings", "default_route_settings", b"default_route_settings", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_log_settings", b"access_log_settings", "api_id", b"api_id", "auto_deploy", b"auto_deploy", "client_certificate_id", b"client_certificate_id", "default_route_settings", b"default_route_settings", "deployment_id", b"deployment_id", "description", b"description", "resource_info", b"resource_info", "route_settings", b"route_settings", "stage_name", b"stage_name", "stage_variables", b"stage_variables", "tags", b"tags"]) -> None: ...

global___Stage = Stage

@typing_extensions.final
class RouteParameterConstraints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REQUIRED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    required: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        required: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["required", b"required", "resource_info", b"resource_info"]) -> None: ...

global___RouteParameterConstraints = RouteParameterConstraints

@typing_extensions.final
class RouteResponseParameterConstraints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REQUIRED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    required: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        required: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["required", b"required", "resource_info", b"resource_info"]) -> None: ...

global___RouteResponseParameterConstraints = RouteResponseParameterConstraints



from abc import ABC, abstractmethod
from glob import glob
import tempfile
import atexit
from typing import Iterator, AnyStr
from braceexpand import braceexpand

from core.bp_metadata_utils.git_utils import sync_remote_repo_to_local
from core.bp_metadata_utils.policy import Policy


class PolicyRepo(ABC):
    """Class to hold the common functionality for policy repositories."""

    def __init__(self, url: str, local_path='', skip_sync=False) -> None:
        """
        Constructs a base class for the specialized repositories of policies.
        param url: Url to clone/pull policies from.
        param local_path: Path to where the repo should be cloned. If not supplied a temp directory will be created.
        param skip_sync: When set to True, the initialization of the repo will be skipped - use for testing purposes
        only (to speed-up tests).
        """
        self._url = url
        self._base_url = self._url.rstrip('.git')
        self._local_path = local_path

        if not self._local_path:
            self._working_dir = tempfile.TemporaryDirectory(prefix='repo-policies-')
            self._local_path = self._working_dir.name
            atexit.register(self._working_dir.cleanup)

        if not skip_sync:
            sync_remote_repo_to_local(repo_url=url, local_path=self._local_path)

    @property
    @abstractmethod
    def glob_pattern(self) -> str:
        """
        It is the responsibility of the specialized repositories to provide the
        pattern where the policies are stored - typically only a small section of the
        repo contains the policies. Hence, the need for a search pattern.
        """
        pass


    @abstractmethod
    def filter(self, policy: Policy) -> bool:
        """
        Determines whether a supplied policy has to be filtered-out.
        Some policies are not interesting to us (ex., Azure internal policies which customers
        have no control over). Hence, this function is used to allow the specialized repositories
        to indicate which policies should be ignored.
        param policy: Policy to examine.
        """
        pass

    @abstractmethod
    def pre_filter(self, policy_file_path: str) -> bool:
        """
        Determines whether a supplied policy file has to be filtered-out.
        Unlike the filter method, this method makes the decision solely based on the name of the file.
        param policy_file_path: Policy's file to examine.
        """
        pass

    @property
    def policy_file_paths(self) -> Iterator[AnyStr]:
        expanded_paths = []
        # for p in braceexpand(self.glob_pattern): # This was preventing the blueprint execution, is there a reason for this library?
            # expanded_paths.extend(glob(p, recursive=True))
        expanded_paths.extend(glob(self.glob_pattern, recursive=True))

        return expanded_paths

    def __str__(self):
        return f'URL {self._url},' \
               f' local_path: {self._local_path}, ' \
               f'glob_pattern: {self.glob_pattern}, ' \
               f'policy_file_paths: {list(self.policy_file_paths)}'







# Copyright 2017-2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may
# not use this file except in compliance with the License. A copy of the License is located at
#
#        http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
'''
Rule Name:
  ALB_HTTP_TO_HTTPS_REDIRECTION_CHECK

Description:
  Checks whether HTTP to HTTPS redirection is configured.

Trigger:
  Periodic

Reports on:
  AWS::ElasticLoadBalancingV2::LoadBalancer

Rule Parameters:
  None

Scenarios:
  Scenario: 1
     Given: No Application Load Balancer is present
      Then: Return NOT_APPLICABLE
  Scenario: 2
     Given: There is at least 1 Application Load Balancer
       And: Application Load Balancer has only HTTPS listener(s)
      Then: Return COMPLIANT
  Scenario: 3
     Given: There is at least 1 Application Load Balancer
       And: Application Load Balancer has one or more HTTP listeners configured
       And: At least one HTTP listener rule does not have HTTP to HTTPS redirection action configured
      Then: Return NON_COMPLIANT
  Scenario: 4
     Given: There is at least 1 Application Load Balancer
       And: Application Load Balancer has one or more HTTP listeners configured
       And: All HTTP listener rules have HTTP to HTTPS redirection action configured
      Then: Return COMPLIANT
'''

def add(i: int, j: int) -> int:
    """
    Adds two integers and returns the sum
    :param i: First int.
    :param j: Second int.
    :return: The sum of i and j
    """
    return i + j